@@ -50,7 +50,8 @@ protected:
 };
 
 // libstdc++/12790
-// basic_filebuf::seekpos() should call codecvt::unshift()
+// basic_filebuf::seekpos() should call codecvt::unshift(),
+// but only if writing
 void test01()
 {
   using namespace std;
@@ -62,16 +63,14 @@ void test01()
   locale loc(locale::classic(), cvt);
 
   wfilebuf fb;
-  fb.pubsetbuf(0, 0);
   fb.pubimbue(loc);
 
   fb.open(name, ios_base::out);
   streampos pos = fb.pubseekoff(0, ios_base::beg);
-  fb.sputc(L'a');
 
   VERIFY( !cvt->unshift_called );
   fb.pubseekpos(pos);
-  VERIFY( cvt->unshift_called );
+  VERIFY( !cvt->unshift_called );
 }
 
 int main()
